@@ -3,7 +3,6 @@
 ######################################################################
 
 package Verilog::Netlist::Port;
-use Class::Struct;
 
 use Verilog::Netlist;
 use Verilog::Netlist::Subclass;
@@ -12,7 +11,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::Port::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.212';
+$VERSION = '3.251';
 
 structs('_new_base',
 	'Verilog::Netlist::Port::Struct'
@@ -55,6 +54,8 @@ sub delete {
 
 sub netlist { return $_[0]->module->netlist; }
 
+sub logger { return $_[0]->netlist->logger; }
+
 sub type {  # Backward compatibility only
     my $self=shift;
     if ($#_ >= 0) { $self->data_type(@_); }
@@ -189,7 +190,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2009 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2010 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
