@@ -14,7 +14,7 @@ use base qw(DynaLoader);
 use strict;
 use vars qw($VERSION $Debug);
 
-$VERSION = '3.230';
+$VERSION = '3.251';
 
 #$Debug sets the default value for debug.  You're better off with the object method though.
 
@@ -73,6 +73,7 @@ sub new {
 		);
 
     $self->{use_cb_contassign} = $self->{use_vars} if !exists $self->{use_cb_contassign};
+    $self->{use_cb_defparam} = $self->{use_vars} if !exists $self->{use_cb_defparam};
     $self->{use_cb_pin}    = $self->{use_vars} if !exists $self->{use_cb_pin};
     $self->{use_cb_port}   = $self->{use_vars} if !exists $self->{use_cb_port};
     $self->{use_cb_var}    = $self->{use_vars} if !exists $self->{use_cb_var};
@@ -176,7 +177,9 @@ sub parse_preproc_file {
 
     ref($pp) or croak "%Error: not passed a Verilog::Preproc object";
     $self->reset();
-    while (defined(my $text = $pp->getall)) {
+
+    # Chunk size of ~32K determined experimentally with t/49_largeish.t
+    while (defined(my $text = $pp->getall(31*1024))) {
 	$self->parse ($text);
     }
     $self->eof;
@@ -331,9 +334,9 @@ included (no callbacks will be involed) when suspected to be necessary.
 Adding "use_unreadback => 0" will disable later use of the unreadback
 method, which may improve performance.
 
-Adding "use_vars => 0" will disable contassign, pin, var and port callbacks to
-Verilog::SigParser.  This can greatly speed parsing when variable and
-interconnect information is not required.
+Adding "use_vars => 0" will disable contassign, defparam, pin, var and port
+callbacks to Verilog::SigParser.  This can greatly speed parsing when
+variable and interconnect information is not required.
 
 =item $parser->callback_names ()
 
