@@ -14,12 +14,15 @@ use base qw(Verilog::Parser);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.212';
+$VERSION = '3.251';
 
 our @_Callback_Names = qw(
   attribute
+  contassign
+  defparam
   endcell
   endinterface
+  endmodport
   endtaskfunc
   endmodule
   endpackage
@@ -28,6 +31,7 @@ our @_Callback_Names = qw(
   import
   instant
   interface
+  modport
   module
   package
   parampin
@@ -62,7 +66,8 @@ sub metacomment {
 # Accessors
 
 sub callback_names {
-    return sort @_Callback_Names;
+    my @out = sort @_Callback_Names;
+    return @out;
 }
 
 #######################################################################
@@ -90,6 +95,18 @@ sub comment {
 # The my's aren't needed since we do nothing, but are useful if the
 # user copies them from here to their program.
 
+sub contassign {
+    my $self = shift;
+    my $lhs = shift;
+    my $rhs = shift;
+}
+
+sub defparam {
+    my $self = shift;
+    my $lhs = shift;
+    my $rhs = shift;
+}
+
 sub endcell {
     my $self = shift;
 }
@@ -98,6 +115,10 @@ sub endinterface {
     my $self = shift;
 }
 
+sub endmodport {
+    my $self = shift;
+}
+
 sub endtaskfunc {
     my $self = shift;
 }
@@ -140,6 +161,12 @@ sub interface {
     my $name = shift;
 }
 
+sub modport {
+    my $self = shift;
+    my $keyword = shift;
+    my $name = shift;
+}
+
 sub module {
     my $self = shift;
     my $keyword = shift;
@@ -261,6 +288,18 @@ of each comment line (C<//key rest> to end of line) or comment block
 (C</*key rest */).  It calls C<$self->attribute( meta_text )>
 if the first word has a true value in hash C<$self->metacomment>.
 
+=item $self->contassign ( $token, $lhs, $rhs )
+
+This method is called at a continuous "assign" keyword, with the left and
+right hand part of the assignment.  Note that "wire" initializations are
+not considered assignments; those are received via the var callback's value
+parameter.
+
+=item $self->defparam ( $token, $lhs, $rhs )
+
+This method is called at a "defparam" keyword, with the left and right hand
+part of the assignment.
+
 =item $self->endcell ( $token )
 
 This method is called at the end of defining a cell. It is useful for
@@ -276,6 +315,11 @@ clean up routines.
 This method is called at a endfunction or endtask keyword.  It is useful
 for writing clean up routines.
 
+=item $self->endmodport ( $token )
+
+This method is called at a endmodport keyword. It is useful for writing
+clean up routines.
+
 =item $self->endmodule ( $token )
 
 This method is called at a endmodule keyword. It is useful for writing
@@ -315,6 +359,10 @@ this callback. This has been replaced with the parampin callback.
 
 This method is called when an interface is defined.
 
+=item $self->modport ( $keyword, $name )
+
+This method is called when an interface modport is defined.
+
 =item $self->module ( $keyword, $name, ignored, $in_celldefine )
 
 This method is called when a module is defined.
@@ -336,6 +384,9 @@ This method is called when a pin on a instant is defined.  If a pin name
 was not provided and the connection is by position, name will be '' or
 undef.
 
+If you do not need the pin nor var nor port callbacks, consider the
+"$self->new (... use_vars=>0 ...)"  option to accelerate parsing.
+
 =item $self->port ( $name, $objof, $direction, $data_type, $array, $pinnum )
 
 This method is called when a module port is defined.  It may be called
@@ -344,12 +395,16 @@ port header, the second call at the input/output declaration.
 
 The first argument $name, is the name of the port.  $objof is what the port
 is an object of ('module', 'function', etc).  $direction is the port
-direction ('input', 'output', 'inout', 'ref', 'const ref').  $data_type is
-the data type ('reg', 'user_type_t', 'signed [31:0]', etc).  $array is the
+direction ('input', 'output', 'inout', 'ref', 'const ref', or 'interface').
+$data_type is the data type ('reg', 'user_type_t', 'signed [31:0]', etc, or
+for interfaces the "{interface_id}.{modport_name}").  $array is the
 arraying of the port ('[1:0][2:0]', '', etc).  $pinnum is set to the pin
 number for ANSI style declarations, and 0 for Verilog 1995 declarations
 made outside the port list.
 
+If you do not need the pin nor var nor port callbacks, consider the
+"$self->new (... use_vars=>0 ...)"  option to accelerate parsing.
+
 =item $self->ppdefine ( $defvar, $definition )
 
 This method is called when a preprocessor definition is encountered.
@@ -383,6 +438,9 @@ or expression).
 Note typedefs are included here, because "parameter type" is both a
 variable and a type declaration.
 
+If you do not need the pin nor var nor port callbacks, consider the
+"$self->new (... use_vars=>0 ...)"  option to accelerate parsing.
+
 Below are some example declarations and the callbacks:
 
    reg [4:0]  vect = 5'b10100;
@@ -416,7 +474,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2009 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2010 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
